{% menuitems 'profile-menu' %} 
	{% navitem 'profile' %}My profile{% endnavitem %}
    {% navitem 'auth_password_change' %}Change password{% endnavitem %}
    {% navitem 'profile-options' %}Opt-ins{% endnavitem %}
{% endmenuitems %}